@@ -6,12 +6,14 @@ This is the Kodexa CLI, it can be used to allow you to work with an instance of
 
 It supports interacting with the API, listing and viewing components.  Note it can also be used to login and logout
 """
+import glob
 import json
 import logging
 import os
 import os.path
 import tarfile
 from getpass import getpass
+from pathlib import Path
 
 import click
 from rich import print
@@ -90,7 +92,7 @@ def push_model(_: Info, path: str, url: str, org: str, token: str):
 
     # We need to open the model.yml - upload the contents
     # and then update the metadata
-    with open(path+"/model.yml", "r") as model_meta_file:
+    with open(path + "/model.yml", "r") as model_meta_file:
         import yaml
         model_meta = yaml.safe_load(model_meta_file)
 
@@ -104,9 +106,16 @@ def push_model(_: Info, path: str, url: str, org: str, token: str):
     remote_model_store = RemoteModelStore.parse_obj(model_meta)
     KodexaPlatform.deploy(ref, remote_model_store, force_replace=True)
 
+    print("Deleting existing contents")
+    for path in remote_model_store.list_contents():
+        remote_model_store.delete(path)
+
     for path in model_meta["contents"]:
-        with open(path, 'rb') as path_content:
-            remote_model_store.put(path, path_content, replace=True)
+        for path_hit in glob.glob(path):
+            print(f"Uploading {path_hit}")
+            if Path(path_hit).is_file():
+                with open(path_hit, 'rb') as path_content:
+                    remote_model_store.put(path_hit, path_content, replace=True)
 
     remote_model_store.set_content_metadata(ModelContentMetadata.parse_obj(model_meta['metadata']))
 
@@ -195,7 +204,6 @@ def platform(_: Info, python: bool):
 @click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
 @pass_info
 def delete(_: Info, object_type: str, ref: str, url: str, token: str):
-
     KodexaPlatform.set_url(url)
     KodexaPlatform.set_access_token(token)
     KodexaPlatform.delete(object_type, ref)
@@ -220,11 +228,6 @@ def login(_: Info):
     Once successfully logged in, calls to remote actions, pipelines, and workflows will be made to the
     platform that was set via this login function and will use the stored PAT for authentication.
 
-    Args:
-      _: Info: 
-
-    Returns:
-
     """
     try:
         kodexa_url = input("Enter the Kodexa URL (https://platform.kodexa.com): ")
@@ -243,14 +246,8 @@ def login(_: Info):
 @click.option('--path', default=os.getcwd(), help='Path to folder container kodexa.yml')
 @pass_info
 def document(_: Info, path: str):
-    """Build markdown documentation for this extension
-
-    Args:
-      _: Info: 
-      path: str: 
-
-    Returns:
-
+    """
+    Build markdown documentation for this extension
     """
     metadata = ExtensionHelper.load_metadata(path)
     print("Metadata loaded")
@@ -269,7 +266,6 @@ def document(_: Info, path: str):
 @click.option('--url', default='http://www.example.com/', help='The base URL for the site links')
 @pass_info
 def package(_: Info, path: str, output: str, version: str, site: bool, sitedir: str, url: str):
-
     metadata_obj = ExtensionHelper.load_metadata(path)
     print("Preparing to pack")
     try:
