@@ -1123,6 +1123,21 @@ class ContentNode(object):
         """
         return [i.name for i in self.get_features_of_type("tag")]
 
+    def get_tag_features(self):
+        """Returns a list of the features that are tags on the given node
+
+
+        :return: A list of the tag name
+
+        Args:
+
+        Returns:
+
+        >>> document.content_node.select('*').get_tag_features()
+            [ContentFeature()]
+        """
+        return [i for i in self.get_features_of_type("tag")]
+
     def get_tag_values(self, tag_name, include_children=False):
         """Get the values for a specific tag name
 
@@ -1144,21 +1159,27 @@ class ContentNode(object):
 
         return values
 
-    def get_related_tag_values(self, tag_name: str, include_children: bool = False, value_separator: str = ' '):
+    def get_related_tag_values(self, tag_name: str, include_children: bool = False, value_separator: str = ' ',
+                               tag_uuid=None):
         """Get the values for a specific tag name, grouped by uuid
 
         Args:
           tag_name (str): tag name
           include_children (bool): include the children of this node
           value_separator (str): the string to be used to join related tag values
+          tag_uuid (optional(str)): limit to the given tag uuid
 
         Returns:
           a list of the tag values
 
         """
 
-        def group_tag_values(group_dict, feature_val):
+        def group_tag_values(group_dict, feature_val, tag_uuid):
             # we know the names of all these tags are the same, but we want to group them if they share the same uuid
+
+            if feature_val['uuid'] != tag_uuid:
+                return
+
             if feature_val['uuid'] in value_groups.keys():
                 # we've seen this UUID - add it's value to the group
                 group_dict[feature_val['uuid']].append(feature_val['value'])
@@ -1179,7 +1200,7 @@ class ContentNode(object):
                     tag_feature_vals = [tag_feature_vals]
 
                 for v in tag_feature_vals:
-                    group_tag_values(value_groups, v)
+                    group_tag_values(value_groups, v, tag_uuid)
 
         value_strings = []
         for k in value_groups.keys():
@@ -1187,12 +1208,13 @@ class ContentNode(object):
 
         return value_strings
 
-    def get_related_tag_nodes(self, tag_name: str, include_children: bool = False):
+    def get_related_tag_nodes(self, tag_name: str, include_children: bool = False, tag_uuid=None):
         """Get the nodes for a specific tag name, grouped by uuid
 
         Args:
           tag_name (str): tag name
           include_children (bool): include the children of this node
+          tag_uuid (optional(str)): if set we will only get nodes related to this tag UUID
 
         Returns:
           a list of the tag content nodes
@@ -1211,6 +1233,9 @@ class ContentNode(object):
             tag_instances = tagged_node.get_tag(tag_name)
 
             for tag_instance in tag_instances:
+                if tag_uuid and tag_instance['uuid'] != tag_uuid:
+                    continue
+
                 if tag_instance['uuid'] not in node_groups:
                     node_groups[tag_instance['uuid']] = [tagged_node]
                 else:
@@ -2016,7 +2041,8 @@ class Document(object):
         else:
             # We will assume the input is of byte type
             import tempfile
-            fp = tempfile.NamedTemporaryFile(suffix='.kddb', delete=False)
+            from kodexa import KodexaPlatform
+            fp = tempfile.NamedTemporaryFile(suffix='.kddb', delete=False, dir=KodexaPlatform.get_tempdir())
             fp.write(input)
             fp.close()
             return Document(kddb_path=fp.name, delete_on_close=True)
