@@ -722,6 +722,11 @@ class KodexaPlatform:
             logger.warning(r.text)
             raise Exception("Unable to reindex check your reference and platform settings")
 
+    @classmethod
+    def get_tempdir(cls):
+        import tempfile
+        return os.getenv('KODEXA_TMP', tempfile.gettempdir())
+
 
 class RemoteSession:
     """A Session on the Kodexa platform for leveraging pipelines and services"""
