@@ -10,6 +10,7 @@ from kodexa import ContentEvent, ContentNode, Document, DocumentActor, DocumentT
     TableDataStore, TransitionType
 from kodexa.assistant.assistant import AssistantMetadata
 from kodexa.model import AssistantEvent, ContentObjectReference, DocumentStore, ActorType
+from kodexa.model.objects import ScheduledEvent, ExceptionDetails
 
 logger = logging.getLogger('kodexa.testing')
 
@@ -255,7 +256,7 @@ class AssistantTestHarness:
 
         return self.assistant.process_event(assistant_event, assistant_context)
 
-    def test_scheduled_event(self, scheduled_event: AssistantEvent) -> AssistantResponse:
+    def test_scheduled_event(self, scheduled_event: ScheduledEvent) -> AssistantResponse:
         """
         Pass a scheduled event into the assistant
 
@@ -344,6 +345,22 @@ class OptionException(Exception):
     pass
 
 
+class ExceptionBuilder:
+    """
+    A helper to build an exception details from the last exception
+    """
+
+    @staticmethod
+    def build_exception_details():
+        import sys
+        import better_exceptions
+        et, ev, tb = sys.exc_info()
+        return ExceptionDetails(**{'errorType': et.__name__, 'errorMessage': str(ev),
+                                                'message': "An unexpected exception has occurred",
+                                                'help': "\n".join(
+                                                    better_exceptions.format_exception(*sys.exc_info()))})
+
+
 class ExtensionPackUtil:
     """
     A utility that can be used to access an action defined in a kodexa.yml.
@@ -454,7 +471,7 @@ class ExtensionPackUtil:
         return AssistantTestHarness(assistant, stores, self.file_path, assistant_metadata)
 
     def get_assistant(self, assistant_slug, options=None):
-        """Create an instance of an assistant from the kodexa metadata
+        """Create an instance of an assistant from the Kodexa metadata
 
         Args:
           assistant_slug: param options:
